function [T,d,f] = micmac(D,k,time)
// Returns the vectors of indirect influences and indirect dependences and the matrix of indirect influences according with the MICMAC method.
//
// Calling Sequence
//  [T,d,f]=micmac(D,k)
//  [T,d,f]=micmac(D,k,time)
//
// Parameters
//  time: Value for the time parameter desired in case of polynomial matrix. Is mandatory in such case.
// k: Value of the parameter for the MICMAC method, look the bibliography.
// D: Matrix of direct influences.
// f: Name of the variable to store the indirect influences vector.
// d: Name of the variable to store the indirect dependences vector.
// T: Name of the variable to store the indirect influences matrix.
//
// Description
// This function gives the vector of indirect influences and dependences and the matrix of indirect influences of a given matrix of direct influences according with the MICMAC method.
// If the matrix of direct influences has polynomial entries the function needs the time parameter. For more info look the bibliography.
//
// Examples
// D = [1 0 1;0 0 0;0 0 6] // Define the matrix of direct influences.
// [T,d,f] = micmac(D,2)  // Returns the matrix of indirect influences T, the vector of indirect dependences d and the vector of indirect influences f.
// [T,d,f] = micmac(D,3)  // The same as above but with k equal to 3.
// t=poly(0,'t')  // Define the variable t.
// D = [t 1-t;t^2 1] // Define a 2x2 matrix with polynomial entries.
// [T,d,f] = micmac(D,1) // Apply the MICMAC method to matrix D, the function ask for a time parameter.
//
// See also
//  influence
//  dependence
//  micmac
//  pagerank
//  pwp
//  heatkernel
//
// Authors
//  Jorge Catumba ;
// Bibliography
//   Indirect Influences, Rafael Díaz. preprint http://arxiv.org/abs/0906.1610v1
//   Cálculo de Influencias Indirectas en Scilab. Rafael Díaz, Jorge Catumba.

  if (typeof(D)=="polynomial") then
    T1=D^k
    C=coeff(T1)
    n=size(T1,"c")
		m=size(C,"c")
		if (time > m/n-1) then
			error('The time parameter is to high')
		else
    	    T=C(:,time*n+1:(time+1)*n)
		end
  else  
    T=D^k
  end
  
  d=dependence(T)
  f=influence(T)

endfunction